@@ -1,6 +1,6 @@
 package Pcore::App::Controller::Ext;
 
-use Pcore -const, -role, -result;
+use Pcore -const, -role;
 use Pcore::Ext;
 use Pcore::Util::Data qw[to_json];
 use Pcore::Util::Scalar qw[is_plain_arrayref];
@@ -122,7 +122,7 @@ sub _return_html ( $self, $req ) {
         # Ext locale
         push $resources->@*, $ext_framework->ext_locale( $EXT_FRAMEWORK, $locale, $self->{app}->{devel} );
 
-        # TODO calc checksum 'sha384-' . P->digest->sha384_b64( $res->body->$* );
+        # TODO calc checksum 'sha384-' . P->digest->sha384_b64( $res->{body}->$* );
         push $resources->@*, qq[<script src="$self->{path}overrides.js" integrity="" crossorigin="anonymous"></script>];
         push $resources->@*, qq[<script src="$self->{path}app.js?locale=$locale" integrity="" crossorigin="anonymous"></script>];
 
