@@ -2,7 +2,6 @@ package Pcore::Ext::Context::Call;
 
 use Pcore -class;
 use Pcore::Util::Data qw[to_json];
-use Pcore::Util::Text qw[decode_utf8];
 use Pcore::Util::Scalar qw[refaddr];
 
 has ext => ( is => 'ro', isa => InstanceOf ['Pcore::Ext::Context'], required => 1 );
@@ -22,7 +21,7 @@ sub to_js ( $self ) {
     my $js;
 
     if ( my $args = $self->{func_args} ) {
-        $js = "$self->{func_name}(" . join( q[,], map { decode_utf8 to_json( $_, readable => 1 )->$* } $args->@* ) . q[)];
+        $js = "$self->{func_name}(" . join( q[,], map { to_json( $_, canonical => 1 )->$* } $args->@* ) . q[)];
     }
     else {
         $js = "$self->{func_name}()";
